tlbx: just some common utilities
================================

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Installation
------------

```shell
$ pip install tlbx
```

To install from source and setup development in your virtual environment:

```shell
$ git clone https://github.com/totalhack/tlbx.git
$ cd tlbx
$ pip install -e .
$ pre-commit install
```
